@@ -20,12 +20,20 @@ import typing as t
 from elastic_transport import ObjectApiResponse
 
 from ._base import NamespacedClient
-from .utils import SKIP_IN_PATH, _quote, _rewrite_parameters
+from .utils import (
+    SKIP_IN_PATH,
+    Stability,
+    Visibility,
+    _availability_warning,
+    _quote,
+    _rewrite_parameters,
+)
 
 
 class AutoscalingClient(NamespacedClient):
 
     @_rewrite_parameters()
+    @_availability_warning(Stability.STABLE, Visibility.PRIVATE)
     async def delete_autoscaling_policy(
         self,
         *,
@@ -46,7 +54,7 @@ class AutoscalingClient(NamespacedClient):
 
         `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-autoscaling-delete-autoscaling-policy>`_
 
-        :param name: the name of the autoscaling policy
+        :param name: Name of the autoscaling policy
         :param master_timeout: Period to wait for a connection to the master node. If
             no response is received before the timeout expires, the request fails and
             returns an error.
@@ -81,6 +89,7 @@ class AutoscalingClient(NamespacedClient):
         )
 
     @_rewrite_parameters()
+    @_availability_warning(Stability.STABLE, Visibility.PRIVATE)
     async def get_autoscaling_capacity(
         self,
         *,
@@ -134,6 +143,7 @@ class AutoscalingClient(NamespacedClient):
         )
 
     @_rewrite_parameters()
+    @_availability_warning(Stability.STABLE, Visibility.PRIVATE)
     async def get_autoscaling_policy(
         self,
         *,
@@ -153,7 +163,7 @@ class AutoscalingClient(NamespacedClient):
 
         `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-autoscaling-get-autoscaling-capacity>`_
 
-        :param name: the name of the autoscaling policy
+        :param name: Name of the autoscaling policy
         :param master_timeout: Period to wait for a connection to the master node. If
             no response is received before the timeout expires, the request fails and
             returns an error.
@@ -186,6 +196,7 @@ class AutoscalingClient(NamespacedClient):
     @_rewrite_parameters(
         body_name="policy",
     )
+    @_availability_warning(Stability.STABLE, Visibility.PRIVATE)
     async def put_autoscaling_policy(
         self,
         *,
@@ -208,7 +219,7 @@ class AutoscalingClient(NamespacedClient):
 
         `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-autoscaling-put-autoscaling-policy>`_
 
-        :param name: the name of the autoscaling policy
+        :param name: Name of the autoscaling policy
         :param policy:
         :param master_timeout: Period to wait for a connection to the master node. If
             no response is received before the timeout expires, the request fails and
