@@ -39,8 +39,8 @@ class QueryRulesClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Delete a query rule.
-          Delete a query rule within a query ruleset.
+          <p>Delete a query rule.</p>
+          <p>Delete a query rule within a query ruleset.
           This is a destructive action that is only recoverable by re-adding the same rule with the create or update query rule API.</p>
 
 
@@ -92,8 +92,8 @@ class QueryRulesClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Delete a query ruleset.
-          Remove a query ruleset and its associated data.
+          <p>Delete a query ruleset.</p>
+          <p>Remove a query ruleset and its associated data.
           This is a destructive action that is not recoverable.</p>
 
 
@@ -138,8 +138,8 @@ class QueryRulesClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Get a query rule.
-          Get details about a query rule within a query ruleset.</p>
+          <p>Get a query rule.</p>
+          <p>Get details about a query rule within a query ruleset.</p>
 
 
         `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-query-rules-get-rule>`_
@@ -190,8 +190,8 @@ class QueryRulesClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Get a query ruleset.
-          Get details about a query ruleset.</p>
+          <p>Get a query ruleset.</p>
+          <p>Get details about a query ruleset.</p>
 
 
         `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-query-rules-get-ruleset>`_
@@ -237,8 +237,8 @@ class QueryRulesClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Get all query rulesets.
-          Get summarized information about the query rulesets.</p>
+          <p>Get all query rulesets.</p>
+          <p>Get summarized information about the query rulesets.</p>
 
 
         `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-query-rules-list-rulesets>`_
@@ -294,8 +294,8 @@ class QueryRulesClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Create or update a query rule.
-          Create or update a query rule within a query ruleset.</p>
+          <p>Create or update a query rule.</p>
+          <p>Create or update a query rule within a query ruleset.</p>
           <p>IMPORTANT: Due to limitations within pinned queries, you can only pin documents using ids or docs, but cannot use both in single rule.
           It is advised to use one or the other in query rulesets, to avoid errors.
           Additionally, pinned queries have a maximum limit of 100 pinned hits.
@@ -380,8 +380,8 @@ class QueryRulesClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Create or update a query ruleset.
-          There is a limit of 100 rules per ruleset.
+          <p>Create or update a query ruleset.</p>
+          <p>There is a limit of 100 rules per ruleset.
           This limit can be increased by using the <code>xpack.applications.rules.max_rules_per_ruleset</code> cluster setting.</p>
           <p>IMPORTANT: Due to limitations within pinned queries, you can only select documents using <code>ids</code> or <code>docs</code>, but cannot use both in single rule.
           It is advised to use one or the other in query rulesets, to avoid errors.
@@ -442,8 +442,8 @@ class QueryRulesClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Test a query ruleset.
-          Evaluate match criteria against a query ruleset to identify the rules that would match that criteria.</p>
+          <p>Test a query ruleset.</p>
+          <p>Evaluate match criteria against a query ruleset to identify the rules that would match that criteria.</p>
 
 
         `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-query-rules-test>`_
