@@ -23,16 +23,16 @@ from ._base import NamespacedClient
 from .utils import (
     SKIP_IN_PATH,
     Stability,
+    _availability_warning,
     _quote,
     _rewrite_parameters,
-    _stability_warning,
 )
 
 
 class RollupClient(NamespacedClient):
 
     @_rewrite_parameters()
-    @_stability_warning(Stability.EXPERIMENTAL)
+    @_availability_warning(Stability.EXPERIMENTAL)
     async def delete_job(
         self,
         *,
@@ -67,7 +67,7 @@ class RollupClient(NamespacedClient):
           </code></pre>
 
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/rollup-delete-job.html>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-rollup-delete-job>`_
 
         :param id: Identifier for the job.
         """
@@ -95,7 +95,7 @@ class RollupClient(NamespacedClient):
         )
 
     @_rewrite_parameters()
-    @_stability_warning(Stability.EXPERIMENTAL)
+    @_availability_warning(Stability.EXPERIMENTAL)
     async def get_jobs(
         self,
         *,
@@ -108,14 +108,14 @@ class RollupClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Get rollup job information.
-          Get the configuration, stats, and status of rollup jobs.</p>
+          <p>Get rollup job information.</p>
+          <p>Get the configuration, stats, and status of rollup jobs.</p>
           <p>NOTE: This API returns only active (both <code>STARTED</code> and <code>STOPPED</code>) jobs.
           If a job was created, ran for a while, then was deleted, the API does not return any details about it.
           For details about a historical rollup job, the rollup capabilities API may be more useful.</p>
 
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/rollup-get-job.html>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-rollup-get-jobs>`_
 
         :param id: Identifier for the rollup job. If it is `_all` or omitted, the API
             returns all rollup jobs.
@@ -147,7 +147,7 @@ class RollupClient(NamespacedClient):
         )
 
     @_rewrite_parameters()
-    @_stability_warning(Stability.EXPERIMENTAL)
+    @_availability_warning(Stability.EXPERIMENTAL)
     async def get_rollup_caps(
         self,
         *,
@@ -160,8 +160,8 @@ class RollupClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Get the rollup job capabilities.
-          Get the capabilities of any rollup jobs that have been configured for a specific index or index pattern.</p>
+          <p>Get the rollup job capabilities.</p>
+          <p>Get the capabilities of any rollup jobs that have been configured for a specific index or index pattern.</p>
           <p>This API is useful because a rollup job is often configured to rollup only a subset of fields from the source index.
           Furthermore, only certain aggregations can be configured for various fields, leading to a limited subset of functionality depending on that configuration.
           This API enables you to inspect an index and determine:</p>
@@ -171,7 +171,7 @@ class RollupClient(NamespacedClient):
           </ol>
 
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/rollup-get-rollup-caps.html>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-rollup-get-rollup-caps>`_
 
         :param id: Index, indices or index-pattern to return rollup capabilities for.
             `_all` may be used to fetch rollup capabilities from all jobs.
@@ -203,7 +203,7 @@ class RollupClient(NamespacedClient):
         )
 
     @_rewrite_parameters()
-    @_stability_warning(Stability.EXPERIMENTAL)
+    @_availability_warning(Stability.EXPERIMENTAL)
     async def get_rollup_index_caps(
         self,
         *,
@@ -216,8 +216,8 @@ class RollupClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Get the rollup index capabilities.
-          Get the rollup capabilities of all jobs inside of a rollup index.
+          <p>Get the rollup index capabilities.</p>
+          <p>Get the rollup capabilities of all jobs inside of a rollup index.
           A single rollup index may store the data for multiple rollup jobs and may have a variety of capabilities depending on those jobs. This API enables you to determine:</p>
           <ul>
           <li>What jobs are stored in an index (or indices specified via a pattern)?</li>
@@ -225,7 +225,7 @@ class RollupClient(NamespacedClient):
           </ul>
 
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/rollup-get-rollup-index-caps.html>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-rollup-get-rollup-index-caps>`_
 
         :param index: Data stream or index to check for rollup capabilities. Wildcard
             (`*`) expressions are supported.
@@ -266,7 +266,7 @@ class RollupClient(NamespacedClient):
         ),
         ignore_deprecated_options={"headers"},
     )
-    @_stability_warning(Stability.EXPERIMENTAL)
+    @_availability_warning(Stability.EXPERIMENTAL)
     async def put_job(
         self,
         *,
@@ -295,7 +295,7 @@ class RollupClient(NamespacedClient):
           <p>Jobs are created in a <code>STOPPED</code> state. You can start them with the start rollup jobs API.</p>
 
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/rollup-put-job.html>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-rollup-put-job>`_
 
         :param id: Identifier for the rollup job. This can be any alphanumeric string
             and uniquely identifies the data that is associated with the rollup job.
@@ -392,7 +392,7 @@ class RollupClient(NamespacedClient):
     @_rewrite_parameters(
         body_fields=("aggregations", "aggs", "query", "size"),
     )
-    @_stability_warning(Stability.EXPERIMENTAL)
+    @_availability_warning(Stability.EXPERIMENTAL)
     async def rollup_search(
         self,
         *,
@@ -412,38 +412,17 @@ class RollupClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Search rolled-up data.
-          The rollup search endpoint is needed because, internally, rolled-up documents utilize a different document structure than the original data.
+          <p>Search rolled-up data.</p>
+          <p>The rollup search endpoint is needed because, internally, rolled-up documents utilize a different document structure than the original data.
           It rewrites standard Query DSL into a format that matches the rollup documents then takes the response and rewrites it back to what a client would expect given the original query.</p>
           <p>The request body supports a subset of features from the regular search API.
           The following functionality is not available:</p>
           <p><code>size</code>: Because rollups work on pre-aggregated data, no search hits can be returned and so size must be set to zero or omitted entirely.
           <code>highlighter</code>, <code>suggestors</code>, <code>post_filter</code>, <code>profile</code>, <code>explain</code>: These are similarly disallowed.</p>
-          <p><strong>Searching both historical rollup and non-rollup data</strong></p>
-          <p>The rollup search API has the capability to search across both &quot;live&quot; non-rollup data and the aggregated rollup data.
-          This is done by simply adding the live indices to the URI. For example:</p>
-          <pre><code>GET sensor-1,sensor_rollup/_rollup_search
-          {
-            &quot;size&quot;: 0,
-            &quot;aggregations&quot;: {
-               &quot;max_temperature&quot;: {
-                &quot;max&quot;: {
-                  &quot;field&quot;: &quot;temperature&quot;
-                }
-              }
-            }
-          }
-          </code></pre>
-          <p>The rollup search endpoint does two things when the search runs:</p>
-          <ul>
-          <li>The original request is sent to the non-rollup index unaltered.</li>
-          <li>A rewritten version of the original request is sent to the rollup index.</li>
-          </ul>
-          <p>When the two responses are received, the endpoint rewrites the rollup response and merges the two together.
-          During the merging process, if there is any overlap in buckets between the two responses, the buckets from the non-rollup index are used.</p>
+          <p>For more detailed examples of using the rollup search API, including querying rolled-up data only or combining rolled-up and live data, refer to the External documentation.</p>
 
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/rollup-search.html>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-rollup-rollup-search>`_
 
         :param index: A comma-separated list of data streams and indices used to limit
             the request. This parameter has the following rules: * At least one data
@@ -503,7 +482,7 @@ class RollupClient(NamespacedClient):
         )
 
     @_rewrite_parameters()
-    @_stability_warning(Stability.EXPERIMENTAL)
+    @_availability_warning(Stability.EXPERIMENTAL)
     async def start_job(
         self,
         *,
@@ -516,12 +495,12 @@ class RollupClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Start rollup jobs.
-          If you try to start a job that does not exist, an exception occurs.
+          <p>Start rollup jobs.</p>
+          <p>If you try to start a job that does not exist, an exception occurs.
           If you try to start a job that is already started, nothing happens.</p>
 
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/rollup-start-job.html>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-rollup-start-job>`_
 
         :param id: Identifier for the rollup job.
         """
@@ -549,7 +528,7 @@ class RollupClient(NamespacedClient):
         )
 
     @_rewrite_parameters()
-    @_stability_warning(Stability.EXPERIMENTAL)
+    @_availability_warning(Stability.EXPERIMENTAL)
     async def stop_job(
         self,
         *,
@@ -564,8 +543,8 @@ class RollupClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Stop rollup jobs.
-          If you try to stop a job that does not exist, an exception occurs.
+          <p>Stop rollup jobs.</p>
+          <p>If you try to stop a job that does not exist, an exception occurs.
           If you try to stop a job that is already stopped, nothing happens.</p>
           <p>Since only a stopped job can be deleted, it can be useful to block the API until the indexer has fully stopped.
           This is accomplished with the <code>wait_for_completion</code> query parameter, and optionally a timeout. For example:</p>
@@ -575,7 +554,7 @@ class RollupClient(NamespacedClient):
           If the specified time elapses without the job moving to STOPPED, a timeout exception occurs.</p>
 
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/rollup-stop-job.html>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-rollup-stop-job>`_
 
         :param id: Identifier for the rollup job.
         :param timeout: If `wait_for_completion` is `true`, the API blocks for (at maximum)
