@@ -44,7 +44,7 @@ class SqlClient(NamespacedClient):
           <p>Clear an SQL search cursor.</p>
 
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/clear-sql-cursor-api.html>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-sql-clear-cursor>`_
 
         :param cursor: Cursor to clear.
         """
@@ -89,8 +89,8 @@ class SqlClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Delete an async SQL search.
-          Delete an async SQL search or a stored synchronous SQL search.
+          <p>Delete an async SQL search.</p>
+          <p>Delete an async SQL search or a stored synchronous SQL search.
           If the search is still running, the API cancels it.</p>
           <p>If the Elasticsearch security features are enabled, only the following users can use this API to delete a search:</p>
           <ul>
@@ -99,7 +99,7 @@ class SqlClient(NamespacedClient):
           </ul>
 
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/delete-async-sql-search-api.html>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-sql-delete-async>`_
 
         :param id: The identifier for the search.
         """
@@ -145,12 +145,12 @@ class SqlClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Get async SQL search results.
-          Get the current status and available results for an async SQL search or stored synchronous SQL search.</p>
+          <p>Get async SQL search results.</p>
+          <p>Get the current status and available results for an async SQL search or stored synchronous SQL search.</p>
           <p>If the Elasticsearch security features are enabled, only the user who first submitted the SQL search can retrieve the search using this API.</p>
 
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/get-async-sql-search-api.html>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-sql-get-async>`_
 
         :param id: The identifier for the search.
         :param delimiter: The separator for CSV results. The API supports this parameter
@@ -208,11 +208,11 @@ class SqlClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Get the async SQL search status.
-          Get the current status of an async SQL search or a stored synchronous SQL search.</p>
+          <p>Get the async SQL search status.</p>
+          <p>Get the current status of an async SQL search or a stored synchronous SQL search.</p>
 
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/get-async-sql-search-status-api.html>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-sql-get-async-status>`_
 
         :param id: The identifier for the search.
         """
@@ -253,6 +253,7 @@ class SqlClient(NamespacedClient):
             "keep_on_completion",
             "page_timeout",
             "params",
+            "project_routing",
             "query",
             "request_timeout",
             "runtime_mappings",
@@ -283,8 +284,9 @@ class SqlClient(NamespacedClient):
         keep_alive: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         keep_on_completion: t.Optional[bool] = None,
         page_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
-        params: t.Optional[t.Mapping[str, t.Any]] = None,
+        params: t.Optional[t.Sequence[t.Any]] = None,
         pretty: t.Optional[bool] = None,
+        project_routing: t.Optional[str] = None,
         query: t.Optional[str] = None,
         request_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         runtime_mappings: t.Optional[t.Mapping[str, t.Mapping[str, t.Any]]] = None,
@@ -297,11 +299,11 @@ class SqlClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Get SQL search results.
-          Run an SQL request.</p>
+          <p>Get SQL search results.</p>
+          <p>Run an SQL request.</p>
 
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/sql-search-api.html>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-sql-query>`_
 
         :param allow_partial_search_results: If `true`, the response has partial results
             when there are shard request timeouts or shard failures. If `false`, the
@@ -332,6 +334,10 @@ class SqlClient(NamespacedClient):
             is no longer available. Subsequent scroll requests prolong the lifetime of
             the scroll cursor by the duration of `page_timeout` in the scroll request.
         :param params: The values for parameters in the query.
+        :param project_routing: Specifies a subset of projects to target using project
+            metadata tags in a subset of Lucene query syntax. Allowed Lucene queries:
+            the _alias tag and a single value (possibly wildcarded). Examples: _alias:my-project
+            _alias:_origin _alias:*pr* Supported in serverless only.
         :param query: The SQL query to run.
         :param request_timeout: The timeout before the request fails.
         :param runtime_mappings: One or more runtime fields for the search request. These
@@ -382,6 +388,8 @@ class SqlClient(NamespacedClient):
                 __body["page_timeout"] = page_timeout
             if params is not None:
                 __body["params"] = params
+            if project_routing is not None:
+                __body["project_routing"] = project_routing
             if query is not None:
                 __body["query"] = query
             if request_timeout is not None:
@@ -422,12 +430,12 @@ class SqlClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Translate SQL into Elasticsearch queries.
-          Translate an SQL search into a search API request containing Query DSL.
+          <p>Translate SQL into Elasticsearch queries.</p>
+          <p>Translate an SQL search into a search API request containing Query DSL.
           It accepts the same request body parameters as the SQL search API, excluding <code>cursor</code>.</p>
 
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/sql-translate-api.html>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-sql-translate>`_
 
         :param query: The SQL query to run.
         :param fetch_size: The maximum number of rows (or entries) to return in one response.
