@@ -21,11 +21,12 @@ from ..._sync.client.utils import (
     CLIENT_META_SERVICE,
     SKIP_IN_PATH,
     Stability,
+    Visibility,
+    _availability_warning,
     _base64_auth_header,
     _quote,
     _quote_query,
     _rewrite_parameters,
-    _stability_warning,
     client_node_configs,
     is_requests_http_auth,
     is_requests_node_class,
@@ -40,9 +41,10 @@ __all__ = [
     "_TYPE_HOSTS",
     "SKIP_IN_PATH",
     "Stability",
+    "Visibility",
     "client_node_configs",
     "_rewrite_parameters",
-    "_stability_warning",
+    "_availability_warning",
     "is_requests_http_auth",
     "is_requests_node_class",
 ]
