@@ -24,10 +24,11 @@
 from datetime import datetime
 from ipaddress import ip_address
 from typing import TYPE_CHECKING, Any, AsyncIterator, Dict, List, Optional, Tuple, Union
+from zoneinfo import ZoneInfo
 
+import numpy as np
 import pytest
 from pytest import raises
-from pytz import timezone
 
 from elasticsearch import AsyncElasticsearch, ConflictError, NotFoundError
 from elasticsearch.dsl import (
@@ -47,6 +48,7 @@ from elasticsearch.dsl import (
     Mapping,
     MetaField,
     Nested,
+    NumpyDenseVector,
     Object,
     Q,
     RankFeatures,
@@ -57,6 +59,7 @@ from elasticsearch.dsl import (
 from elasticsearch.dsl.query import Match
 from elasticsearch.dsl.types import MatchQuery
 from elasticsearch.dsl.utils import AttrList
+from elasticsearch.helpers import pack_dense_vector
 from elasticsearch.helpers.errors import BulkIndexError
 
 snowball = analyzer("my_snow", tokenizer="standard", filter=["lowercase", "snowball"])
@@ -432,24 +435,21 @@ async def test_get_with_tz_date(async_data_client: AsyncElasticsearch) -> None:
     )
     assert first_commit is not None
 
-    tzinfo = timezone("Europe/Prague")
+    tzinfo = ZoneInfo("Europe/Prague")
     assert (
-        tzinfo.localize(datetime(2014, 5, 2, 13, 47, 19, 123000))
-        == first_commit.authored_date
+        datetime(2014, 5, 2, 13, 47, 19, 123000, tzinfo) == first_commit.authored_date
     )
 
 
 @pytest.mark.anyio
 async def test_save_with_tz_date(async_data_client: AsyncElasticsearch) -> None:
-    tzinfo = timezone("Europe/Prague")
+    tzinfo = ZoneInfo("Europe/Prague")
     first_commit = await Commit.get(
         id="3ca6e1e73a071a705b4babd2f581c91a2a3e5037", routing="elasticsearch-dsl-py"
     )
     assert first_commit is not None
 
-    first_commit.committed_date = tzinfo.localize(
-        datetime(2014, 5, 2, 13, 47, 19, 123456)
-    )
+    first_commit.committed_date = datetime(2014, 5, 2, 13, 47, 19, 123456, tzinfo)
     await first_commit.save()
 
     first_commit = await Commit.get(
@@ -458,8 +458,7 @@ async def test_save_with_tz_date(async_data_client: AsyncElasticsearch) -> None:
     assert first_commit is not None
 
     assert (
-        tzinfo.localize(datetime(2014, 5, 2, 13, 47, 19, 123456))
-        == first_commit.committed_date
+        datetime(2014, 5, 2, 13, 47, 19, 123456, tzinfo) == first_commit.committed_date
     )
 
 
@@ -865,25 +864,47 @@ async def test_dense_vector(
         float_vector: List[float] = mapped_field(DenseVector())
         byte_vector: List[int] = mapped_field(DenseVector(element_type="byte"))
         bit_vector: List[int] = mapped_field(DenseVector(element_type="bit"))
+        numpy_float_vector: np.ndarray = mapped_field(NumpyDenseVector())
+        packed_float_vector: List[float] = mapped_field(DenseVector())
+        packed_numpy_float_vector: np.ndarray = mapped_field(NumpyDenseVector())
 
         class Index:
             name = "vectors"
 
+        def clean(self):
+            # pack the dense vectors before they are sent to Elasticsearch
+            self.packed_float_vector = pack_dense_vector(self.packed_float_vector)
+            self.packed_numpy_float_vector = pack_dense_vector(
+                self.packed_numpy_float_vector
+            )
+
     await Doc._index.delete(ignore_unavailable=True)
     await Doc.init()
 
+    test_float_vector = [1.0, 1.2, 2.3]
+    test_byte_vector = [12, 23, 34, 45]
+    test_bit_vector = [18, -43, -112]
+
     doc = Doc(
-        float_vector=[1.0, 1.2, 2.3],
-        byte_vector=[12, 23, 34, 45],
-        bit_vector=[18, -43, -112],
+        float_vector=test_float_vector,
+        byte_vector=test_byte_vector,
+        bit_vector=test_bit_vector,
+        numpy_float_vector=np.array(test_float_vector),
+        packed_float_vector=test_float_vector,
+        packed_numpy_float_vector=np.array(test_float_vector, dtype=np.float32),
     )
     await doc.save(refresh=True)
 
     docs = await Doc.search().execute()
     assert len(docs) == 1
-    assert [round(v, 1) for v in docs[0].float_vector] == doc.float_vector
-    assert docs[0].byte_vector == doc.byte_vector
-    assert docs[0].bit_vector == doc.bit_vector
+    assert [round(v, 1) for v in docs[0].float_vector] == test_float_vector
+    assert docs[0].byte_vector == test_byte_vector
+    assert docs[0].bit_vector == test_bit_vector
+    assert type(docs[0].numpy_float_vector) is np.ndarray
+    assert [round(v, 1) for v in docs[0].numpy_float_vector] == test_float_vector
+    assert [round(v, 1) for v in docs[0].packed_float_vector] == test_float_vector
+    assert type(docs[0].packed_numpy_float_vector) is np.ndarray
+    assert [round(v, 1) for v in docs[0].packed_numpy_float_vector] == test_float_vector
 
 
 @pytest.mark.anyio
